@@ -3,7 +3,7 @@ TOMCAT_DST_FOLDER="tomcat"
 TOMCAT_VERSION="8.5.47"
 TOMCAT_PID_FILENAME="tomcat.pid"
 SMARTGEAR_DISTRIBUTION_DIRECTORY=$(ls -d smartgears-distribution-*)
-SMARTGEAR_ROOT=${PWD}
+SMARTGEAR_ROOT=/var/lib/jenkins
 
 BUNDLE_HOME=${SMARTGEAR_ROOT}
 STARTUP_SCRIPT="startContainer.sh"
